package com.dgtly.web.controller.system;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import com.dgtly.system.domain.OrderSalesParameter;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.dgtly.common.annotation.Log;
import com.dgtly.common.enums.BusinessType;
import com.dgtly.system.domain.AlertConfiguration;
import com.dgtly.system.service.IAlertConfigurationService;
import com.dgtly.common.core.controller.BaseController;
import com.dgtly.common.core.domain.AjaxResult;
import com.dgtly.common.utils.poi.ExcelUtil;
import com.dgtly.common.core.page.TableDataInfo;

/**
 * 弹框配置Controller
 * 
 * @author chenyn
 * @date 2023-06-13
 */
@Controller
@RequestMapping("/system/configuration")
public class AlertConfigurationController extends BaseController
{
    //前端代码路径
    private String prefix = "system/alertConfiguration";

    @Autowired
    private IAlertConfigurationService alertConfigurationService;

    @RequiresPermissions("system:configuration:view")
    @GetMapping()
    public String configuration()
    {
        return prefix + "/configuration";
    }

    /**
     * 查询弹框配置列表
     */
    @RequiresPermissions("system:configuration:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(AlertConfiguration alertConfiguration)
    {
        startPage();
        List<AlertConfiguration> list = alertConfigurationService.selectAlertConfigurationList(alertConfiguration);
        return getDataTable(list);
    }

    /**
     * 导出弹框配置列表
     */
    @RequiresPermissions("system:configuration:export")
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(AlertConfiguration alertConfiguration)
    {
        List<AlertConfiguration> list = alertConfigurationService.selectAlertConfigurationList(alertConfiguration);
        ExcelUtil<AlertConfiguration> util = new ExcelUtil<AlertConfiguration>(AlertConfiguration.class);
        return util.exportExcel(list, "configuration");
    }

    /**
     * 新增弹框配置
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存弹框配置
     */
    @RequiresPermissions("system:configuration:add")
    @Log(title = "弹框配置", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(AlertConfiguration alertConfiguration)
    {
        int num = alertConfigurationService.selectAlertConfigurationListFilter(alertConfiguration);
        if ( num==1){
            return error("弹幕通知只能有一个启动，请修改后重新添加");
        }
        return toAjax(alertConfigurationService.insertAlertConfiguration(alertConfiguration));
    }

    /**
     * 修改弹框配置
     */
    @GetMapping("/edit/{alertId}")
    public String edit(@PathVariable("alertId") Long alertId, ModelMap mmap)
    {
        AlertConfiguration alertConfiguration = alertConfigurationService.selectAlertConfigurationById(alertId);
        mmap.put("alertConfiguration", alertConfiguration);
        return prefix + "/edit";
    }
    /**
     * 修改保存弹框配置
     */
    @RequiresPermissions("system:configuration:edit")
    @Log(title = "弹框配置", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(AlertConfiguration alertConfiguration)
    {
        if(("0").equals(alertConfiguration.getAlertStatus())){
            return toAjax(alertConfigurationService.updateAlertConfiguration(alertConfiguration));
        }
        return error("请取消发布后再做修改");
    }
    /**
     * 是否发布/取消发布弹框配置
     */
    @RequiresPermissions("system:configuration:edit")
    @Log(title = "发布弹框", businessType = BusinessType.UPDATE)
    @PostMapping("/release")
    @ResponseBody
    public AjaxResult release(AlertConfiguration alertConfiguration)
    {
       if(alertConfiguration.getAlertStatus().equals("0")){
           return toAjax(alertConfigurationService.updateAlertConfiguration(alertConfiguration));
       }else{
           int num = alertConfigurationService.selectAlertConfigurationListFilter(alertConfiguration);
           if(num==1){
               return AjaxResult.error("已发布该组织弹框,请核查");
           }else {
               return toAjax(alertConfigurationService.updateAlertConfiguration(alertConfiguration));
           }

       }
    }

    /**
     * 删除弹框配置
     */
    @RequiresPermissions("system:configuration:remove")
    @Log(title = "弹框配置", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(alertConfigurationService.deleteAlertConfigurationByIds(ids));
    }


}
