package com.dgtly.web.controller.system;

import java.util.List;

import com.dgtly.common.config.Global;
import com.dgtly.common.utils.StringUtils;
import com.dgtly.common.utils.file.FileUploadUtils;
import com.dgtly.common.utils.file.FileUtils;
import com.dgtly.system.domain.SysUser;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;
import com.dgtly.common.annotation.Log;
import com.dgtly.common.core.controller.BaseController;
import com.dgtly.common.core.domain.AjaxResult;
import com.dgtly.common.core.page.TableDataInfo;
import com.dgtly.common.enums.BusinessType;
import com.dgtly.framework.util.ShiroUtils;
import com.dgtly.system.domain.SysNotice;
import com.dgtly.system.service.ISysNoticeService;
import org.springframework.web.multipart.MultipartFile;

/**
 * 公告 信息操作处理
 * 
 * @author dgtly
 */
@Controller
@RequestMapping("/system/notice")
public class SysNoticeController extends BaseController
{
    private String prefix = "system/notice";

    @Autowired
    private ISysNoticeService noticeService;

    @RequiresPermissions("system:notice:view")
    @GetMapping()
    public String notice()
    {
        return prefix + "/notice";
    }

    /**
     * 查询公告列表
     */
    @RequiresPermissions("system:notice:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(SysNotice notice)
    {
        startPage();
        notice.setCompanyId(ShiroUtils.getCompanyId());
        List<SysNotice> list = noticeService.selectNoticeListByRole(notice);
        return getDataTable(list);
    }

    /**
     * 新增公告
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存公告
     */
    @RequiresPermissions("system:notice:add")
    @Log(title = "通知公告", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(SysNotice notice,MultipartFile file)
    {


            if(StringUtils.isNotEmpty(notice.getFmzFile())){
                //获取base64文件后缀
                String houzhui = notice.getFmzFile().split(";")[0].split("\\/")[1];
                //获取base64值
                String base64 = notice.getFmzFile().substring( notice.getFmzFile().indexOf(",") + 1);

                //base64转文件 并返回展示url
                String fileUrl = FileUploadUtils.base64ToFile(base64,FileUploadUtils.getDefaultBaseDir()+"/content",System.currentTimeMillis()+"."+houzhui);
                notice.setFmzFileUrl(fileUrl);
            }
            notice.setCompanyId(ShiroUtils.getCompanyId());
            notice.setCreateBy(ShiroUtils.getLoginName());
            return toAjax(noticeService.insertNotice(notice));




    }

    /**
     * 修改公告
     */
    @GetMapping("/edit/{noticeId}")
    public String edit(@PathVariable("noticeId") Long noticeId, ModelMap mmap)
    {
        mmap.put("notice", noticeService.selectNoticeById(noticeId));
        return prefix + "/edit";
    }

    /**
     * 修改保存公告
     */
    @RequiresPermissions("system:notice:edit")
    @Log(title = "通知公告", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(SysNotice notice)
    {
        if(StringUtils.isNotEmpty(notice.getFmzFileUrl())){
            //获取base64文件后缀
            String houzhui = notice.getFmzFileUrl().split(";")[0].split("\\/")[1];
            //获取base64值
            String base64 = notice.getFmzFileUrl().substring( notice.getFmzFileUrl().indexOf(",") + 1);

            //base64转文件 并返回展示url
            String fileUrl = FileUploadUtils.base64ToFile(base64,FileUploadUtils.getDefaultBaseDir()+"/content",System.currentTimeMillis()+"."+houzhui);
            notice.setFmzFileUrl(fileUrl);
        }
        notice.setUpdateBy(ShiroUtils.getLoginName());
        return toAjax(noticeService.updateNotice(notice));
    }

    /**
     * 删除公告
     */
    @RequiresPermissions("system:notice:remove")
    @Log(title = "通知公告", businessType = BusinessType.DELETE)
    @PostMapping("/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(noticeService.deleteNoticeByIds(ids));
    }
}
