package com.dgtly.apiframework.interceptor;

import com.auth0.jwt.JWT;
import com.auth0.jwt.JWTVerifier;
import com.auth0.jwt.algorithms.Algorithm;
import com.auth0.jwt.exceptions.JWTDecodeException;
import com.auth0.jwt.exceptions.JWTVerificationException;
import com.dgtly.common.exception.api.ApiTokenTimeoutException;
import com.dgtly.common.exception.api.NoLoginException;
import com.dgtly.common.annotation.ApiPassToken;

import com.dgtly.system.domain.SysUser;
import com.dgtly.system.service.ISysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.method.HandlerMethod;
import org.springframework.web.servlet.HandlerInterceptor;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
/*企业微信应用  放过token校验*/
@Component
public class AuthenticationInterceptor implements HandlerInterceptor {

    @Autowired
    private ISysUserService sysUserService;

    @Override
    public boolean preHandle(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object object) throws Exception {
        //因为必须在企业微信中才能那个登录  所以放开登录token验证
        if(1==1){
            return true;
        }


        String token = httpServletRequest.getHeader("token");// 从 http 请求头中取出 token
        // 如果不是映射到方法直接通过
        if(!(object instanceof HandlerMethod)){
            return true;
        }
        HandlerMethod handlerMethod=(HandlerMethod)object;
        String handlerPackage = handlerMethod.getBeanType().getPackage().getName();
        String thisPackage = this.getClass().getPackage().getName();
        String verifPackage =thisPackage.substring(0,thisPackage.indexOf(".",thisPackage.indexOf(".")+1));
        /*只对代码中的请求进行验证*/
        if(handlerPackage.indexOf(verifPackage)==-1){
            return true;
        }

        ApiPassToken a1=handlerMethod.getBeanType().getAnnotation(ApiPassToken.class);
        ApiPassToken a2 = handlerMethod.getMethodAnnotation(ApiPassToken.class);
        //检查是否有passtoken注释，有则跳过认证
        if (a1!=null||a2!=null) {
             return true;
        }
        //检查有没有需要用户权限的注解

        if (token == null) {
            throw new NoLoginException();
        }
        // 获取 token 中的 user id
        Long userId;
        try {
            userId = Long.parseLong(JWT.decode(token).getAudience().get(0));
        } catch (JWTDecodeException j) {
            /*密码错误*/
            throw new NoLoginException();
        }
        SysUser user = sysUserService.selectUserById(userId);
        if (user == null) {
            throw new NoLoginException();
        }
        // 验证 token
        JWTVerifier jwtVerifier = JWT.require(Algorithm.HMAC256(user.getPassword())).build();
        try {
            jwtVerifier.verify(token);
        } catch (JWTVerificationException e) {
            throw new ApiTokenTimeoutException();
        }
        return true;
    }

    @Override
    public void postHandle(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object o, ModelAndView modelAndView) throws Exception {

    }
    @Override
    public void afterCompletion(HttpServletRequest httpServletRequest, HttpServletResponse httpServletResponse, Object o, Exception e) throws Exception {

    }
}