package com.dgtly.system.mapper;


import com.dgtly.system.domain.Customer;
import com.dgtly.system.domain.CustomersVo;
import com.dgtly.system.domain.DataMasterCustomerVO;
import org.apache.ibatis.annotations.MapKey;

import java.util.List;
import java.util.Map;

/**
 * 经销商 Mapper接口
 * 
 * @author dgtly
 * @date 2020-08-27
 */
public interface CustomerMapper
{
    /**
     * 查询经销商 
     * 
     * @param id 经销商 ID
     * @return 经销商 
     */
    public Customer selectCustomersById(Long id);

    public Customer selectCustomersByChainsCode(String chainsCode);

    /**
     * 查询经销商 列表
     * 
     * @param customers 经销商 
     * @return 经销商 集合
     */
    public List<Customer> selectCustomersList(Customer customers);

    /**
     * 新增经销商 
     * 
     * @param customers 经销商 
     * @return 结果
     */
    public int insertCustomers(Customer customers);

    /**
     * 修改经销商 
     * 
     * @param customers 经销商 
     * @return 结果
     */
    public int updateCustomers(Customer customers);

    /**
     * 删除经销商 
     * 
     * @param id 经销商 ID
     * @return 结果
     */
    public int deleteCustomersById(Long id);

    /**
     * 批量删除经销商 
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteCustomersByIds(String[] ids);

    @MapKey("code")
    public Map<String, Customer> selectCustomerMapByCode();

    @MapKey("chainsCode")
    public Map<String, Customer> selectCustomerMapByChainsCode();

   public List<DataMasterCustomerVO> selectCustomerCodeByNotStart();

    /**
     * 新增经销商启用
     *
     * @param customersVo 经销商启用
     * @return 结果
     */
    public int insertCustomersStart(CustomersVo customersVo);
}
