package com.dgtly.system.service.impl;

import java.util.List;
import com.dgtly.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.dgtly.system.mapper.TransferLogMapper;
import com.dgtly.system.domain.TransferLog;
import com.dgtly.system.service.ITransferLogService;
import com.dgtly.common.core.text.Convert;

/**
 * 信息传输日志记录Service业务层处理
 * 
 * @author njs
 * @date 2023-04-12
 */
@Service
public class TransferLogServiceImpl implements ITransferLogService 
{
    @Autowired
    private TransferLogMapper transferLogMapper;

    /**
     * 查询信息传输日志记录
     * 
     * @param logId 信息传输日志记录ID
     * @return 信息传输日志记录
     */
    @Override
    public TransferLog selectTransferLogById(Long logId)
    {
        return transferLogMapper.selectTransferLogById(logId);
    }

    /**
     * 查询信息传输日志记录列表
     * 
     * @param transferLog 信息传输日志记录
     * @return 信息传输日志记录
     */
    @Override
    public List<TransferLog> selectTransferLogList(TransferLog transferLog)
    {
        return transferLogMapper.selectTransferLogList(transferLog);
    }

    /**
     * 新增信息传输日志记录
     * 
     * @param transferLog 信息传输日志记录
     * @return 结果
     */
    @Override
    public int insertTransferLog(TransferLog transferLog)
    {
        transferLog.setCreateTime(DateUtils.getNowDate());
        return transferLogMapper.insertTransferLog(transferLog);
    }

    /**
     * 修改信息传输日志记录
     * 
     * @param transferLog 信息传输日志记录
     * @return 结果
     */
    @Override
    public int updateTransferLog(TransferLog transferLog)
    {
        transferLog.setUpdateTime(DateUtils.getNowDate());
        return transferLogMapper.updateTransferLog(transferLog);
    }

    /**
     * 删除信息传输日志记录对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTransferLogByIds(String ids)
    {
        return transferLogMapper.deleteTransferLogByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除信息传输日志记录信息
     * 
     * @param logId 信息传输日志记录ID
     * @return 结果
     */
    @Override
    public int deleteTransferLogById(Long logId)
    {
        return transferLogMapper.deleteTransferLogById(logId);
    }
}
