package com.dgtly.wxportal.service.impl;

import java.util.List;
import com.dgtly.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.dgtly.wxportal.mapper.WxBannerMapper;
import com.dgtly.wxportal.domain.WxBanner;
import com.dgtly.wxportal.service.IWxBannerService;
import com.dgtly.common.core.text.Convert;

/**
 * 企业微信门户首页banner图Service业务层处理
 * 
 * @author qxp
 * @date 2020-06-23
 */
@Service
public class WxBannerServiceImpl implements IWxBannerService 
{
    @Autowired
    private WxBannerMapper wxBannerMapper;

    /**
     * 查询企业微信门户首页banner图
     * 
     * @param bannerId 企业微信门户首页banner图ID
     * @return 企业微信门户首页banner图
     */
    @Override
    public WxBanner selectWxBannerById(Long bannerId)
    {
        return wxBannerMapper.selectWxBannerById(bannerId);
    }

    /**
     * 查询企业微信门户首页banner图列表
     * 
     * @param wxBanner 企业微信门户首页banner图
     * @return 企业微信门户首页banner图
     */
    @Override
    public List<WxBanner> selectWxBannerList(WxBanner wxBanner)
    {
        return wxBannerMapper.selectWxBannerList(wxBanner);
    }

    /**
     * 新增企业微信门户首页banner图
     * 
     * @param wxBanner 企业微信门户首页banner图
     * @return 结果
     */
    @Override
    public int insertWxBanner(WxBanner wxBanner)
    {
        wxBanner.setCreateTime(DateUtils.getNowDate());
        return wxBannerMapper.insertWxBanner(wxBanner);
    }

    /**
     * 修改企业微信门户首页banner图
     * 
     * @param wxBanner 企业微信门户首页banner图
     * @return 结果
     */
    @Override
    public int updateWxBanner(WxBanner wxBanner)
    {
        wxBanner.setUpdateTime(DateUtils.getNowDate());
        return wxBannerMapper.updateWxBanner(wxBanner);
    }

    /**
     * 删除企业微信门户首页banner图对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteWxBannerByIds(String ids)
    {
        return wxBannerMapper.deleteWxBannerByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除企业微信门户首页banner图信息
     * 
     * @param bannerId 企业微信门户首页banner图ID
     * @return 结果
     */
    @Override
    public int deleteWxBannerById(Long bannerId)
    {
        return wxBannerMapper.deleteWxBannerById(bannerId);
    }
}
