package com.dgtly.wxportal.service.impl;

import java.util.List;

import com.dgtly.wxportal.service.IWxQyUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.dgtly.wxportal.mapper.WxQyUserMapper;
import com.dgtly.wxportal.domain.WxQyUser;
import com.dgtly.common.core.text.Convert;

/**
 * 企业微信用户信息Service业务层处理
 * 
 * @author dgtly
 * @date 2020-06-29
 */
@Service
public class WxQyUserServiceImpl implements IWxQyUserService
{
    @Autowired
    private WxQyUserMapper wxQyUserMapper;

    /**
     * 根据系统用户Id解除微信绑定
     * @param userId
     * @return
     */
    @Override
    public int bondedSysUserBySysUserId(Long userId) {
        return wxQyUserMapper.bondedSysUserBySysUserId(userId);
    }

    /**
     * 查询企业微信用户信息
     * 
     * @param userid 企业微信用户信息ID
     * @return 企业微信用户信息
     */
    @Override
    public WxQyUser selectWxQyUserById(String userid)
    {
        return wxQyUserMapper.selectWxQyUserById(userid);
    }

    @Override
    public WxQyUser selectWxQyUserBySysUserId(String sysUserId) {
        return wxQyUserMapper.selectWxQyUserBySysUserId(sysUserId);
    }

    /**
     * 查询企业微信用户信息列表
     * 
     * @param wxQyUser 企业微信用户信息
     * @return 企业微信用户信息
     */
    @Override
    public List<WxQyUser> selectWxQyUserList(WxQyUser wxQyUser)
    {
        return wxQyUserMapper.selectWxQyUserList(wxQyUser);
    }

    /**
     * 新增企业微信用户信息
     * 
     * @param wxQyUser 企业微信用户信息
     * @return 结果
     */
    @Override
    public int insertWxQyUser(WxQyUser wxQyUser)
    {
        return wxQyUserMapper.insertWxQyUser(wxQyUser);
    }

    /**
     * 修改企业微信用户信息
     * 
     * @param wxQyUser 企业微信用户信息
     * @return 结果
     */
    @Override
    public int updateWxQyUser(WxQyUser wxQyUser)
    {
        return wxQyUserMapper.updateWxQyUser(wxQyUser);
    }

    /**
     * 删除企业微信用户信息对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteWxQyUserByIds(String ids)
    {
        return wxQyUserMapper.deleteWxQyUserByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除企业微信用户信息信息
     * 
     * @param userid 企业微信用户信息ID
     * @return 结果
     */
    @Override
    public int deleteWxQyUserById(String userid)
    {
        return wxQyUserMapper.deleteWxQyUserById(userid);
    }
}
